Spline curves
=============

.. autoclass:: splinebox.spline_curves.Spline
   :members:
   :undoc-members:

.. autofunction:: splinebox.spline_curves.padding_function

.. toctree::
   :maxdepth: 1
   :hidden:

   hermite_spline_curves.rst
